#ifndef __RESOURCE_js_H__
#define __RESOURCE_js_H__

#include <gio/gio.h>

G_GNUC_INTERNAL GResource *js_get_resource (void);
#endif
